@@ -1,7 +1,7 @@
 # ABSTRACT: take structured address data and format it according to the various global/country rules
 
 package Geo::Address::Formatter;
-$Geo::Address::Formatter::VERSION = '1.68';
+$Geo::Address::Formatter::VERSION = '1.69';
 use strict;
 use warnings;
 use feature qw(say);
@@ -167,8 +167,8 @@ sub format_address {
     $self->_add_state_code($rh_components);    
     $self->_add_county_code($rh_components);
     
-    say "after adding codes";
-    say Dumper $rh_components;
+    #say "after adding codes";
+    #say Dumper $rh_components;
 
     # add the attention, but only if needed
     my $ra_unknown = $self->_find_unknown_components($rh_components);
@@ -659,7 +659,7 @@ Geo::Address::Formatter - take structured address data and format it according t
 
 =head1 VERSION
 
-version 1.68
+version 1.69
 
 =head1 SYNOPSIS
 
